@@ -172,6 +172,17 @@ _button_clicked (HildonButton *b, TweakrProfileStatusPlugin *plugin)
     g_slist_free (presets);
 }
 
+static void
+_reshow_profile_button_real (GtkWidget *widget,
+                             TweakrProfileStatusPlugin *plugin)
+{
+    if (g_strcmp0 (G_OBJECT_CLASS_NAME (G_OBJECT_GET_CLASS (widget)),
+                   "ProfilesStatusMenuItem")  == 0)
+    {
+        gtk_widget_show (widget);
+    }
+}
+
 static void
 _hide_profile_button_real (GtkWidget *widget,
                           TweakrProfileStatusPlugin *plugin)
@@ -183,8 +194,8 @@ _hide_profile_button_real (GtkWidget *widget,
     }
 }
 
-static void
-_hide_profile_button (TweakrProfileStatusPlugin *plugin, gpointer data)
+static GtkWidget *
+_find_hds_container (TweakrProfileStatusPlugin *plugin)
 {
     GtkWidget *parent;
     const gchar *class_name;
@@ -198,8 +209,30 @@ _hide_profile_button (TweakrProfileStatusPlugin *plugin, gpointer data)
             class_name =
                 G_OBJECT_CLASS_NAME (G_OBJECT_GET_CLASS (G_OBJECT (parent)));
     }
-    if (parent != NULL)
-        gtk_container_foreach (GTK_CONTAINER (parent),
+
+    return parent;
+}
+
+static void
+_reshow_profile_button (TweakrProfileStatusPlugin *plugin, gpointer data)
+{
+    GtkWidget *container;
+
+    container = _find_hds_container (plugin);
+    if (container != NULL)
+        gtk_container_foreach (GTK_CONTAINER (container),
+                               (GtkCallback) _reshow_profile_button_real,
+                               plugin);
+}
+
+static void
+_hide_profile_button (TweakrProfileStatusPlugin *plugin, gpointer data)
+{
+    GtkWidget *container;
+
+    container = _find_hds_container (plugin);
+    if (container != NULL)
+        gtk_container_foreach (GTK_CONTAINER (container),
                                (GtkCallback) _hide_profile_button_real,
                                plugin);
 }
@@ -227,7 +260,8 @@ _create_main_button (TweakrProfileStatusPlugin *plugin)
     image = gtk_image_new_from_icon_name ("general_profile",
                                           GTK_ICON_SIZE_BUTTON);
     hildon_button_set_image (HILDON_BUTTON (plugin->priv->button), image);
-
+    hildon_button_set_style (HILDON_BUTTON (plugin->priv->button),
+                             HILDON_BUTTON_STYLE_PICKER);
     g_signal_connect (G_OBJECT (plugin->priv->button), "clicked",
                       G_CALLBACK (_button_clicked), plugin);
 
@@ -240,6 +274,10 @@ _create_main_button (TweakrProfileStatusPlugin *plugin)
         g_signal_connect (plugin, "realize",
                           G_CALLBACK (_hide_profile_button), NULL);
 
+    g_signal_connect (plugin, "unrealize",
+                      G_CALLBACK (_reshow_profile_button), NULL);
+
+
     gtk_widget_show_all (plugin->priv->button);
 }
 
